﻿using System.ComponentModel;
using System.Windows;
using System;

namespace TheTeachersTimesaverCore.Types
{
    public enum EditingModes
    {
        None,
        Add,
        Edit,
        Load
    }

    public abstract class BaseInfo : DependencyObject, INotifyPropertyChanged
    {
        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        #endregion

        #region OnPropertyChanged
        protected void OnPropertyChanged(string propertyName)
        {
            if (_EditingMode == EditingModes.Load) return;
            PropertyChangedEventHandler handler = this.PropertyChanged;
            if (handler != null) handler(this, new PropertyChangedEventArgs(propertyName));
            if (propertyName == "EditingMode") return;
            if (_EditingMode == EditingModes.None) EditingMode = EditingModes.Edit;
            else if (_EditingMode == EditingModes.Add) HasChangedSinceAdd = true;
        }
        #endregion //OnPropertyChanged

        #region OnStatusChanged
        public event EventHandler<StatusChangedArgs> StatusChanged;
        protected void OnStatusChanged(Int32 Status, String Message)
        {
            if (StatusChanged != null) StatusChanged(this, new StatusChangedArgs() { Status = Status, Message = Message });
        }
        #endregion //OnStatusChanged

        #region EditingMode
        /// <summary>
        /// Store for the EditingMode property.</summary>
        private EditingModes _EditingMode;
        /// <summary>
        /// Editing Mode of current record. Set this property to EditingModes.Add AFTER you have finished initializing a NEW record.</summary>
        public EditingModes EditingMode
        {
            get { return _EditingMode; }
            set
            {
                if (_EditingMode == value) return;
                _EditingMode = value;
                HasChangedSinceAdd = false;
                OnPropertyChanged("EditingMode");
            }
        }
        /// <summary>
        /// If in Add Mode, has the current record changed since it was initialized?</summary>
        public Boolean HasChangedSinceAdd;
        #endregion //EditingMode
    }

    public class StatusChangedArgs : EventArgs
    {
        public Int32 Status { get; set; }
        public String Message { get; set; }
    }
}
